extends RigidBody

var prevPos # the enemy's position in the previous frame

func _ready():
	# activate the _process()-method that is called every frame
	set_process(true)
	# initialize the prevPos variable to the current position
	prevPos = get_global_transform().origin

func _process(delta):
	# calculate the direction from the position in the previous frame to the current position
	var pos = get_global_transform().origin
	var targetDir = (pos-prevPos).normalized()
	# and turn the ship so it looks in the movement direction
	set_global_transform(Transform(createLookatMatrix(targetDir), pos))
	
	# update the prevPos variable so in the next frame it stores this frame's position
	prevPos = pos

# helper method that creates a matrix that turns an object to the desired orientation
func createLookatMatrix(targetDir):
	return Matrix3(-targetDir, Vector3(-targetDir.y, targetDir.x, 0), Vector3(0,0,1))

# this is called when a body enters the shot detection area, i.e. when the enemy is hit by a player bullet
func _on_ShotDetectionArea_body_enter( body ):
	# destroy the enemy
	queue_free()
	
	# if the bullet has a destroy-method call it
	# some bullets like laser rays don't have such a method since they shouldn't vanish when they hit an enemy
	if body.has_method("destroy"):
		body.destroy()