extends KinematicBody

signal killed(numLivesLeft)
signal scoreChanged(newScore)

export(float) var speed = 20.0
export(int) var lives = 3
var score = 0

func _ready():
	set_fixed_process(true)

func _fixed_process(delta):
	# at the start of every frame create a new empty direction variable
	var direction = Vector3(0,0,0)
	
	# check the four movement buttons and change the direction variable accordingly
	if Input.is_action_pressed("move_up"):
		direction.y += 1
	if Input.is_action_pressed("move_down"):
		direction.y -= 1
	if Input.is_action_pressed("move_left"):
		direction.x -= 1
	if Input.is_action_pressed("move_right"):
		direction.x += 1
	
	# move the player in the desired direction
	# the rest variable will contain movement that could not be performed because the player hit something
	var rest = move(direction * delta * speed)
	# if the player hit something
	if is_colliding():
		# slide the player along obstacles
		var remainingPossibleMovement = get_collision_normal().slide(rest)
		# try to move once more if the object slid past the end of the object
		move(remainingPossibleMovement)

func onCollision(other):
	var animPlayer = get_node("AnimationPlayer")
	# if an animation is playing the player is currently respawning or dieing and shouldn't react to bullets
	if not animPlayer.is_playing():
		# reduce the number of lives in the player
		lives -= 1
		# signal all attached objects that the player has died
		emit_signal("killed", lives)
		print("died, lives left: " + str(lives))
		
		# if there are lives left immediately respawn, otherwise play the death animation
		# NOTE: this could also be triggered from the game scene like it is done in the Rollerball demo
		if lives > 0:
			animPlayer.play("Respawn")
		else:
			animPlayer.play("Death")
			# immediately destroy the gun mount to prevent the dieing player from shooting
			get_node("PlayerGunMount").queue_free()

# called by the Death animation
func deleteCollider():
	set_shape_as_trigger(0, true)

# called by the Death animation
func deleteSelf():
	queue_free()

func _on_EnemyCollisionArea_body_enter( body ):
	onCollision(body)
