
extends Spatial

var attackerPositions
# onready var attackerPos = get_node("Path/PathFollow")
export(float) var speed = 10.0
export(float) var spawnDelay = 0.2
var offset = 0
onready var pathNode = get_node("Path")

func _ready():
	# the scene contains one path follow node but we need one for each actor to be spawned
	# so remember the attached node 
	var pathFollowPrototype = get_node("Path/PathFollow")
	pathNode.remove_child(pathFollowPrototype)
	var attackingShips = get_node("Actors").get_children()
	# and for each attached ship
	for ship in attackingShips:
		# create a new copy of the path follow node
		var newPathFollow = pathFollowPrototype.duplicate()
		pathNode.add_child(newPathFollow)
		# and reattach the ship to that new copy
		get_node("Actors").remove_child(ship)
		newPathFollow.add_child(ship)
	
	#detach the path node so the ship templates aren't in the scene before being spawned
	remove_child(pathNode)

func _process(delta):
	# calculate how far the first ship has moved along the path
	offset += delta * speed
	var currentOffset = offset
	
	# for every ship apply that offset and lower it so the next ship is a bit behind it
	for pathFollow in pathNode.get_children():
		pathFollow.set_offset(currentOffset)
		currentOffset -= spawnDelay * speed
		# once a negative offset is reached the following ships aren't even on the path yet
		if currentOffset < 0:
			break

# spawn an instance of attackingShip at the spawner's position
func spawn():
	set_process(true)
	add_child(pathNode)

# callback attached to the area_exit-signal of the Area-node
func _on_Area_area_exit( area ):
	spawn()
	# remove the collision area since it won't be needed anymore and less objects means better performance
	get_node("TriggerArea").queue_free()



