
extends Spatial

export(float) var speed = 25.0

var bullets = []

func _ready():
	# the ammo node is where bullets are attached
	var ammo = get_node("Ammo")
	# remove them, otherwise the template bullets will be visible in the game stuck to the gun
	for bullet in ammo.get_children():
		# remember all bullets so they can be duplicated to create new shots
		bullets.append(bullet)
		ammo.remove_child(bullet)

func shoot():
	# when told to shoot look at every bullet attached to the ammo node of this gun
	for bullet in bullets:
		# duplicate each bullet to create a new shot
		var newShot = bullet.duplicate()
		
		# move the shot into the x-y-plane 
		# since this game is 2.5D no shot should miss the player because it's in front or behind it
		var shotTransform = get_global_transform()
		shotTransform.origin.z = 0
		newShot.set_global_transform(shotTransform)
		
		# also adjust the shot direction so the shot stays in the x-y-plane
		var shotDirection = get_global_transform().basis.x
		shotDirection.z = 0
		newShot.set_linear_velocity(-speed * shotDirection.normalized())
		
		# add the new shot to the root node so it moves independently 
		get_tree().get_root().add_child(newShot)

