
extends Spatial

export(float) var speed = 25.0

var bullets = []

func _ready():
	# the ammo node is where bullets are attached
	var ammo = get_node("Ammo")
	# remove them, otherwise the template bullets will be visible in the game stuck to the gun
	for bullet in ammo.get_children():
		# remember all bullets so they can be duplicated to create new shots
		bullets.append(bullet)
		ammo.remove_child(bullet)

func shoot():
	for bullet in bullets:
		# duplicate each bullet attached to the ammo node
		var newShot = bullet.duplicate()
		
		# place it at the position of the gun and move it into the x-y-plane
		var shotTransform = get_global_transform()
		shotTransform.origin.z = 0
		newShot.set_global_transform(shotTransform)
		
		# set the shot direction and adjust it so it's inside the x-y-plane
		var shotDirection = get_global_transform().basis.x
		shotDirection.z = 0
		# calculate the direction that points 90 degrees from the shot direction
		var sideDirection = Vector3(shotDirection.y, -shotDirection.x, 0)
		# add or substract up to half of that side direction to randomize the shot direction
		shotDirection += sideDirection * (randf() - 0.5)
		newShot.set_linear_velocity(-speed * shotDirection.normalized())
		
		# attach the shot to the root node so it moves independently
		get_tree().get_root().add_child(newShot)

