
extends Spatial

export(float) var speed = 25.0

var bullets = []

func _ready():
	# the ammo node is where bullets are attached
	var ammo = get_node("Ammo")
	# remove them, otherwise the template bullets will be visible in the game stuck to the gun
	for bullet in ammo.get_children():
		# remember all bullets so they can be duplicated to create new shots
		bullets.append(bullet)
		ammo.remove_child(bullet)

func shoot():
	# look up all players in the game
	var players = get_tree().get_nodes_in_group("Players")
	# if there are none there's nothing to shoot at
	if players.size() == 0:
		return
	
	# since in this demo there is only one player just target the first one
	var player = players[0]
	# calculate the directon from the gun to the player
	var shotDirection = player.get_global_transform().origin - get_global_transform().origin
	# adjust the shot direction so the shot stays in the x-y-plane
	shotDirection.z = 0
	
	for bullet in bullets:
		# create a new shot from each bullet template attached to the ammo node
		var newShot = bullet.duplicate()
		
		# place it at the position of the gun and move it into the x-y-plane
		var shotTransform = get_global_transform()
		shotTransform.origin.z = 0
		newShot.set_global_transform(shotTransform)
		
		# set the shot direction
		newShot.set_linear_velocity(speed * shotDirection.normalized())
		
		# attach it to the root node so it moves independently
		get_tree().get_root().add_child(newShot)

